#
# spec file for package nemiver
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define scm_bootstrap 0
Name:           nemiver
Version:        0.9.6
Release:        bp153.1.17
Summary:        Nemiver graphical debugger
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
URL:            http://home.gna.org/nemiver/
Source0:        http://download.gnome.org/sources/nemiver/0.9/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM nemiver-build-fix.patch bgo#763840 zaitor@opensuse.org -- Fix build with new mm stack
Patch0:         nemiver-build-fix.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gdb
BuildRequires:  intltool
BuildRequires:  libgtop-devel
BuildRequires:  pkgconfig
BuildRequires:  sqlite-devel
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gdlmm-3.0) >= 3.0
BuildRequires:  pkgconfig(giomm-2.4) >= 2.15.2
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtkhex-3) >= 2.90
BuildRequires:  pkgconfig(gtkmm-3.0) >= 3.0
BuildRequires:  pkgconfig(gtksourceviewmm-3.0) >= 3.0
BuildRequires:  pkgconfig(vte-2.91) >= 0.28
Requires:       gdb
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires
%if 0%{?scm_bootstrap}
BuildRequires:  gnome-common
%endif
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
Nemiver is a standalone graphical debugger that integrates well in the
GNOME desktop environment. It currently features a backend which uses
the well known GNU Debugger gdb to debug C / C++ programs.

%package devel
Summary:        Nemiver graphical debugger - Development files
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}

%description devel
Nemiver is a standalone graphical debugger that integrates well in the
GNOME desktop environment. It currently features a backend which uses
the well known GNU Debugger gdb to debug C / C++ programs.

This package contains the development files to build debugger backend.

%lang_package

%prep
%setup -q
%patch0 -p1
# Disabled from ver 0.9.6, it breaks the build.
#translation-update-upstream

%build
%if 0%{?scm_bootstrap}
NOCONFIGURE=1 gnome-autogen.sh
%endif
%configure --disable-static --with-pic\
        --enable-gsettings
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file nemiver
%find_lang %{name} %{?no_lang_C}
# remove la files
find %{buildroot} -type f -name "*.la" -delete -print
# create symlinks for man pages
%fdupes -s %{buildroot}/%{_mandir}
# create hardlinks for the rest
%fdupes %{buildroot}

%if 0%{?suse_version} > 1130
%post
%desktop_database_post
%icon_theme_cache_post
%glib2_gsettings_schema_post
%endif

%if 0%{?suse_version} > 1130
%postun
%desktop_database_postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun
%endif

%files
%doc AUTHORS README NEWS TODO
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/*
%{_libdir}/nemiver/
%{_datadir}/nemiver/
%dir %{_datadir}/appdata
%{_datadir}/appdata/nemiver.appdata.xml
%{_datadir}/applications/*
%{_datadir}/glib-2.0/schemas/org.nemiver.gschema.xml
# Own dirs for oS 13.2
%dir %{_datadir}/icons/hicolor/symbolic/
%dir %{_datadir}/icons/hicolor/symbolic/apps
%{_datadir}/icons/hicolor/*/apps/nemiver*.*
%{_mandir}/man1/nemiver.1%{ext_man}

%files devel
%doc AUTHORS README NEWS TODO
%{_includedir}/nemiver/

%files lang -f %{name}.lang

%changelog
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Feb  2 2017 adam.majer@suse.de
- Use individual libboost-*-devel packages instead of boost-devel.
  + Add conditional libboost_headers-devel BuildRequires.
* Sun Jul 24 2016 zaitor@opensuse.org
- Add yet a buildfix commit from upstream to
  nemiver-build-fix.patch.
* Thu Mar 17 2016 zaitor@opensuse.org
- Add nemiver-build-fix.patch: Fix build with new mm stack, patches
  from upstream git, and one from bugzilla (bgo#763840).
* Fri Oct 23 2015 zaitor@opensuse.org
- Own dirs to fix build for openSUSE 13.2.
* Wed Sep 30 2015 zaitor@opensuse.org
- Update to version 0.9.6:
  + Consolidate GErrorSafePtr definitions
  + Port to vte-2.91 API
  + Use c++11 when we use glibmm24 version >= 2.46
  + Consolidate NativeGObjectSafePtr definitions
  + Make all dialogs transient on top of the workbench root window
  + Support vte 2.90 alongside 2.91
  + Misc code & build system cleanup
  + Fix a condition in UString::is_integer
  + Import new boost M4 files from upstream
  + Use BOOSTLIBDIR instead of harcoded path to find boost
  + icon: provide a symbolic variant of the app icon
  + Fix compilation issue in tests/ due to wrong type
  + Fix tr1 and pty.h compilation issues
  + configure.ac: don't fail if gconf is missing
  + Updated translations.
- Disable translation-update-upstream as this breaks the build atm.
- Toggle scm_bootstrap to 0, we are using the upstream tarball.
- Drop %%icon_theme_cache_post/postun script handling for
  HighContrast icon theme, it is removed.
* Wed Sep 24 2014 dimstar@opensuse.org
- Update to version 0.9.5.1411306867.91aaabf:
  + Support VTE 2.91.
  + Updated translations.
- Replace pkgconfig(vte-2.90) BuildRequires with
  pkgconfig(vte-2.91), following upstream.
- Introduce scm_bootstrap defines, allowing to easily
  enable/disable the need to bootstrap (as the current tarball is a
  git checkout):
  + set scm_bootstrap to 1.
  + Conditionally add gnome-common BuildRequires and call to
    gnome-autogen.sh.
* Sun Dec  8 2013 dimstar@opensuse.org
- Update to version 0.9.5:
  + Fixed syntax in .desktop file.
  + Fix "restart loosing inferior argument" bug.
  + Don't 'run' the inferior on startup when it has no 'main'.
  + Continue execution upon (re)start with breakpoints set.
  + Handle deleting all sub-breakpoints at once.
  + Support modified-breakpoint async output from GDB.
  + Allow disassembling from address 0.
  + Fix continue action label.
  + Misc fixes for autoconf 2.69 and automake 1.13.1.
  + Bugs fixed: bgo#680376, bgo#697992, bgo#687609, bgo#561239,
    bgo#700248, bgo#701480, bgo#698371.
- Drop nemiver-fix-desktopfile-syntax.patch: fixed upstream.
- Add %%icon_theme_cache_post/postun script handling for
  HighContrast icon theme additions.
* Wed Mar 13 2013 zaitor@opensuse.org
- Add nemiver-fix-desktopfile-syntax.patch, fix broken syntax in
  .desktop file.
* Mon Jan 14 2013 dimstar@opensuse.org
- Update to version 0.9.4:
  + Added search keywords to .desktop file.
  + Fix well form-ness of gl.po.
  + Fix help browser launching.
  + Ensure workbench body is shown.
  + Added a README.release.txt file.
  + Various code cleanups.
  + Use new documentation infrastructure.
  + Bugs fixed: bgo#689338, bgo#689458, bgo#684046, bgo#670439,
    bgo#689575.
  + Updated translations.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams port to the new documentation infrastructure.
- Drop obsolete --disable-scrollkeeper configure parameter.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 0.9.3:
  + Initial support for monitoring expressions (bgo#542503).
  + Support --just-load command line (bgo#665274).
  + Fix --enable-debuggeronly (bgo#680934).
  + Fix XML validation..
  + Save and restore tty attributes.
  + Various BSDs fixes.
  + Various code cleanups.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 0.9.2:
  + Support renaming of sessions (bgo#543488).
  + Support GDB/MI properties displayint, dynamic, has_more.
  + Support 'new_children' property of GDB/MI changelist LIST.
  + Add a --load-core command line switch.
  + Better default directory in core loading dialog.
  + Various other code changes.
  + Code maintainability enhancements.
  + Bugs fixed: bgo#641595, bgo#664463, bgo#665498, bgo#667677,
    bgo#667723, bgo#670464, bgo#672409.
  + Updated translations.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Nov 20 2011 dimstar@opensuse.org
- Update to version 0.9.1:
  + Handle deprecated functions on glibmm-2.4 2.30.0 and
    glib-2.0 2.31.0
  + Bye bye gziped tarballs, welcome xz
  + Source code tab label completely ellipsized [bgo#664385]
  + Allow shrinking of the memory view widget
  + Relax the fixed minimum sizes preventing shrinking
  + Allow selecting current frame twice consecutively
  + Add cmd line option to choose the gdb binary [bgo#646698]
  + Handle plural form of a string [bgo#659462]
  + Use local time instead of UTC time
  + Updated translations.
* Wed Oct  5 2011 vuntz@opensuse.org
- Enable the pkgconfig(gdlmm-3.0) BuildRequires now that gdlmm is
  in Factory. This enables the dynamic layout feature.
* Mon Sep 19 2011 vuntz@opensuse.org
- Update to version 0.9.0:
  + Port to GNOME 3 technologies.
  + Support user defined assembly syntax
  + New Layout Manager
  + Support Copy/Paste/Reset on target terminal
  + Backend support for GDB/MI variable format
  + Enable GDB pretty printers by default
  + Many other code changes and bug fixes.
  + Updated translations.
- Move to pkgconfig()-style BuildRequires at the same time as
  moving to GNOME 3 technologies:
  + Old ones: ghex-devel, gtkmm2-devel,
    libgtksourceviewmm-2_0-devel.
  + New ones: gtkhex-3, gtkmm-3.0, gtksourceviewmm-3.0.
- Change pkgconfig(vte) BuildRequires to pkgconfig(vte-2.90) for
  the move to GNOME 3 technologies.
- Add explicit pkgconfig(giomm-2.4) BuildRequires: it was implicit
  before.
- Drop --enable-sourceviewmm2 configure option: this is gone with
  the port to GNOME 3.
* Wed May 11 2011 dimstar@opensuse.org
- Update to version 0.8.2:
  + Catch more exceptions at low level
  + Reset command queue on restart GDB after a crash
  + Don't list frame args twice
  + Add a GSettings implementation for IConfMgr
  + Build fixes
  + Bugs fixed: bgo#640919, bgo#640921, bgo#643700, bgo#644114,
    bgo#644569, bgo#560235, bgo#598444.
  + Updated translations.
- Replace vte-devel BuildRequires with pkgconfig(vte).
- Switch to gsettings configuration backend:
  + Replace gconf2-devel BuildRequires with
    pkgconfig(gsettings-desktop-schemas)
  + Pass --enable-gsettings to configure
  + Replace gconf schema macros with gsettings equivalents.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Wed Jan 12 2011 vuntz@opensuse.org
- Update to version 0.8.1:
  + Fix buffer setting in SourceEditor (bgo#633561)
  + Handle BP setting w/o debug info (bgo#634224)
  + Better BP re-setting on restart (bgo#634227)
  + Safer session data clearing (bgo#634228)
  + Don't boldify file path in locate dialog (bgo#633563)
  + Show asm in the right SourceEditor (Closes #633565)
  + Restart without exception (bgo#634406)
  + Treat GDB communication as raw data (bgo#634834)
  + Fix count-point toggling thinko (bgo#635935)
  + Ignore GDB init file on restart (bgo#635928)
  + Allow restarting after GDB dies (bgo#635956)
  + Fix string typo (bgo#633445)
  + Remove dead code
  + Updated translations.
* Fri Oct 22 2010 vuntz@opensuse.org
- Update to version 0.8.0:
  + Support integrated disassembling
  + Support Countpoints
  + Support "filename:linenum" in the set breakpoints dialog
  + Support breaking on fork/exec syscalls
  + Support --remote=HOST:PORT (bgo#624630)
  + Support Lookup source files in inferior's directory
  + Support GDB/MI original-location attribute on pending
    breakpoints
  + Find dialog is no more modal
  + Add a "Debug" preference dialog
  + Ask the user to locate a given file only once
  + Make breakpoint view columns resizable
  + Don't try to look for frame on exit (bgo#630615)
  + Support follow-fork-mode setting (bgo#581377)
  + Support multibytes string parsing (bgo#62730)
  + Remove libglademm dependency and replace with GtkBuilder
    (bgo#590817)
  + Merge the Call Stack and Variables into one tab: Context.
    (bgo#424060)
  + Add a popup when quitting nemiver. (bgo#553217)
  + Other bugs fixed: bgo#419504, bgo#604436, bgo#607782,
    bgo#610808, bgo#611588, bgo#618506, bgo#622796, bgo#625706,
    bgo#626079, bgo#628886, bgo#631925, bgo#630615
  + Various small fixes, code cleanups, and build fixes.
  + Updated translations.
- Drop nemiver-gcc45.patch: fixed upstream.
- Remove libglademm-devel BuildRequires.
- Change Requires of lang package to Recommends.
- Remove explicit devel Requires in devel subpackage: they will be
  added automatically the pkgconfig() way.
- Do not add Development category to nemiver.desktop with
  %%suse_update_desktop_file: it's already there. Also do not use -i
  since it's already installed.
* Tue Mar  2 2010 dimstar@opensuse.org
- Add nemiver-gcc45.patch to fix build with GCC 4.5, patch taken
  from upstram git commit 997874 and extended to also solve
  bgo#611588.
* Mon Dec  7 2009 dimstar@opensuse.org
- Update to version 0.7.3:
  + Support editing breakpoint condition
  + Use -break-after to set ignore count
  + Support ignore count at breakpoint setting time
  + bgo#595083 - Update breakpoint saving into session
  + bgo#505667 - Preselect process to attach to
  + bgo#591327 - Fix command line parsing
  + bgo#599768 - Restore call stack initial window
  + bgo#601199 - Update call stack on thread selection
  + bgo#601819 - Do not update variables twice
  + Properly handle empty command line
  + Cleanup long command line switches
  + bgo#579569 - Escape strings saved in sessions
  + bgo#603627 - Handle ":" in pending bp attrs
  + Small typo causing test build failure
  + bgo#602072 - Let inferior use launch terminal
  + bgo#602074 - Do not blindly truncate types
* Mon Sep 14 2009 vuntz@opensuse.org
- Update to version 0.7.2:
  + Support breakpoint ignore counts (Closes: bgo#588251)
  + Display no msg dialog when gconf is down
  + Create varobjs for a given frame (Closes: bgo#590833)
  + Don't ignore "thread-selected" async records
  + Change IDebugger::thread_selected_signal signature
  + Update state when thread id changes.
  + Don't clobber cmdline arguments (Close: bgo#591327)
  + Updated translations.
* Sun Aug  2 2009 vuntz@novell.com
- Update to version 0.7.1:
  + Support multiple address breakpoints (Closes: bgo#587697)
  + Support original-location in breakpoints (Closes: bgo#588256)
  + Support restarting when GDB dies (Closes: bgo#588313)
  + Don't fall appart when gconfd is down
  + Keep default conf values when gconf is down
  + Fix variable popup tip size issues
  + Var popup tip shouldn't be too small by default
  + Support "text besides icons" visual setting
  + Updated translations.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 0.7.0:
  + Support GDB Variable Objects (Closes: bgo#573678)
  + Properly show reference variable (Closes: bgo#585466)
  + Make pointer dereferencing more intuitive (Closes: bgo#530902)
  + Support variable value editing in variable inspector (Closes:
    bgo#581169)
  + Add watchpoint support (Closes: bgo#386450)
  + Support copying variables to the clipboard (Closes: bgo#547329)
  + Hide var tooltip appropriatly (Closes: bgo#545596)
  + Don't overrun frames vector (Closes: bgo#585516)
  + Keep popup tip under control (Closes: bgo#585657)
  + Awesome up variable popup tip
  + New nmv_abort_on_throw environment variable
  + Allow the ',' separator in NMV_LOG_DOMAINS env var
  + Use AM_SILENT_RULES for nicer compilation output
  + Fix unused variable warning
  + Updated translations.
* Sun May  3 2009 mboman@suse.de
- Update to version 0.6.7:
  + Don't clear session when restarting with different args,
    bgo#568822
  + GDB/MI parsing fixes
  + Debugger API improvements
  + Implement call stack paging, bgo#544116
  + Kill automake warnings when building tests
  + Header inclusion cleanup, bgo##581047
  + Fix compilation breakage when building without gtkhex
  + Performance improvements
  + Fix critical warnings when closing a file, bgo##578736
  + Quote arguments passed to gdb, bgo##575889
  + On going OpenBSD build fixes
  + Translation updates
* Thu Apr 30 2009 vuntz@novell.com
- Add missing posttrans for gconf schemas.
* Sun Apr  5 2009 vuntz@novell.com
- Update to version 0.6.6:
  + Update ephy-spinner widget (bgo#574915)
  + Fix tests to work with Boost.Test 1.37
  + Fix MI parsing error with Archer (bgo#575660)
  + Fix build with gcc 4.1.2 (bgo#572704)
  + Update all of the screenshots for the manual
  + Change serial input to a FileChooserButton (bgo#436057)
  + Enable re-ordering of source file tabs (bgo#545246)
  + Make the 'View > Memory' conditionally used (bgo#564832)
  + Give indication of activity in the 'open file' dialog
    (bgo#564294)
  + Fix File list so keyboard navigation scrolls list again
    (bgo#564294)
  + Scroll 'File Open' list to starting source file (bgo#525512)
  + Ellipsize filename in tab (bgo#565645)
  + Sort columns of process selection dialog displays warning
    (bgo#534700)
  + Improve global variable listing (bgo#573709)
  + Check for empty before isspace in UString::chomp() (bgo#574214)
  + Don't split member vars incorrectly if value has comma
    (bgo#527947)
  + Save session when switching debugging contexts (bgo#575912)
  + Many build fixes for OpenBSD
- Clean up file list.
* Thu Mar 26 2009 crrodriguez@suse.de
- remove static modules and "la" files
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Mon Mar  9 2009 vuntz@novell.com
- Add Requires on gdb (the BuildRequires is not enough to inherit
  this Requires).
* Sun Mar  1 2009 mboman@suse.de
- Update to version 0.6.5:
  + Enlarge the default size of the variable inspector dialog
  + bgo#526151 - Change the 'restart' icon
  + bgo#554405 - Fix libtool wrapper detection for files with
    dashes
  + bgo#530910 – View -> "Show Errors" and "Show Output" should not
    be displayed
  + bgo#536259 - Remember history in var inspector dialog
  + bgo#553213 – tabs are in different order to Alt-1,2,3,4,5
  + bgo#564301 – Assertion when trying to open variable inspector
  + Add a preference for sourceview color theme
  + Hook up the color theme preference
  + Don't link fooprog test program against libnemivercommon, etc.
  + bgo#560662 Refactor the parser and create GDBMParser
  + bgo#560662 - Support singular RESULT parsing.
  + bgo#564113 - GDB/MI parsing error
  + bgo#567175 - Listing Source files from target executable is
    broken
  + bgo#570029 – Print a message on the terminal when the user
    calls a function
  + bgo#568821 - "Call function" dialog should remember history
  + bgo#571036 - Random crash
  + bgo#571099 - nemiver crashes on startup in GtkHex
  + Remove config.h.in from Source Control Manamagement.
  + Fix compilation breakage with gtksourceviewmm-1
  + Make Nemiver compile on gtkmm 2.12
  + Better pretty print when calling functions.
  + Avoid duplicates in call function dialog history.
  + Persist the Variable inspector dialog history
  + Fix compilation with gcc 4.3.3
  + bgo#568785 - Add Debugger category to desktop file
  + bgo#569168 – Cannot locate source with a full file name
  + bgo#562925 - Shorten compilation lines
  + Translation updates
- Remove BuildRequires perl-XML-Parser, libgnome-devel,
  libxml2-devel
- Remove %%if <= 10.2 statements
- Remove %%{release} from Requires
- Remove nemiver-desktop.diff. Fixed upstream
- Don't use %%{suse_update_config -f}
- Remove libxml2-devel and gnomevfs2-devel from Requires in -devel
  section
* Sat Dec 20 2008 mboman@suse.de
- Update to version 0.6.4:
  + bgo#555733 - "Assertion failed: editor" when trying to open a new binary
  + bgo#560377 - support new running async output record in GDB trunk
  + bgo#561287 - crash when doing nemiver --purgesessions
  + bgo#562024 - cannot set breakpoint sometimes
  + Re-arrange columns in call stack view
  + bgo#555732 - Use font specified in the preferences for the output terminal
  + various cleanups: move to new tooltip API, migrate from
    deprecated TreePath APIs
  + bgo#553780 - Status notebook disapearing sometimes
  + bgo#553780 - Compilation speedups and remove __gnu::cxx deprecated
    usage.
* Fri Oct  3 2008 hfiguiere@suse.de
- Fix dependency on libgtksourceviewmm due to update the 2.0 series.
* Thu Sep  4 2008 mboman@novell.com
- Update to 0.6.2
  + conditional breakpoints
  + bgo#548121 - String search not available when program is not running
  + bgo#548118 - Select new node on dereferencing
  + bgo#523377 - first-run prints sql-related errors to console
  + bgo#545842 - Missing shortcut to set a breakpoint in current file
  + bgo#547169 - Set breakpoint to selected function name by default
  + fix boost unit test static library detection
  + fix a configure help string
  + Update website references to point to the new location
  + Translation updates
* Wed Jul 30 2008 hfiguiere@suse.de
- Update to 0.6.1
  * conditional breakpoints
  * arbitrary function calls
  * various code cleanups
  * add --version command line switch
  * support running autogen.sh from other directories dans srcdir
  * bgo#515525 - Arrow keys don't work to navigate through source file
  * bgo#396277 - implement lazy evaluation of status widgets
  * bgo#543798 - don't pop up 'reload file' dialog all the time
  * bgo#543797 - display a meaningful error when inferior is not found
  * bgo#545211 - Bad index management when closing a tab
  * bgo#540934 - documentation docbook XML compliance
  * on going HIG compliance assurance
  * add preferences for controlling behaviour or reloading source files
* Sat Jun 21 2008 hfiguiere@novell.com
- Update to 0.5.4
  * many compilation fixes
  * bgo#537281 unable to open some files because their encoding is not known
  * bgo#539109 can't stop running inferior
  * bgo#499873 Variable 'this' not found
  * bgo#539311 - rhythmbox can loads its plugins under nemiver
  * bgo#534990 - don't install libnemivercommon.pc
  * bgo#535359 "Clicking on current stack frame should show the correct
    source line in the editor"
  * Updated po and oc translations
* Sat Jun  7 2008 hfiguiere@novell.com
- Fix build for 10.3 in OBS
* Fri Jun  6 2008 hfiguiere@novell.com
- Update to 0.5.3
  * bgo#526696 "Detach from the running program" not properly unsensitived"
  * bgo#526866 breakpoint parsing failures
  * bgo#526826 missing dependency in .pc file
  * bgo#527696 nemiver --help only shows libgnome related help messages
  * bgo#526863 Parsing error leaves nemiver in unusable state
  * bgo#527796 remove libgnome dependency
  * bgo#482806 Debugger state and Menu item sensitivity problems
  * bgo#534619 Once detached of a program, you're not sure you're really disconnected
  * add -Wl,--as-needed link flag for DSOs
  * properly set memory editor sensitivity when debugger is running
  * remove obsolete fields from nemiver.desktop file
* Sat Apr 12 2008 hfiguiere@suse.de
- Build with ghex to support the memory view.
- Add libgtop-devel as a requires for the devel package.
* Mon Apr  7 2008 hfiguiere@suse.de
- Update to 0.5.2
  * fix an infinite loop when parsing an output record having a
  line starting with '='
  * support setting breakpoints on functions that are in
  not-yet-loaded shared libraries.
  * Nemiver doesn't propose to stop the debugging application (bgo#526291)
- Add glib2-devel to the Requires for the -devel package
* Thu Apr  3 2008 hfiguiere@suse.de
- Initial checkin
